You've activated the Bader charge in-app guide. In this guide, you will learn how to use the app to compute the Bader charge of bulk PtO.
Click on Step 1: Select structure and follow the instructions to proceed.
In the structure selection step, we select the PtO structure from the examples.
Once selected, we can inspect the structure in the viewer below.

#### Tasks

- Click on the "From examples" tab and select the "Bader charge" category
- Select the PtO structure in the dropdown menu
- Click the Confirm button to proceed

Warning: Changes after confirmation will reset the following steps.

#### Tasks

1. Select Structure as is (we skip the relaxation here)
2. Open step 2.1 for further instructions

#### Tasks

1. Check (activate) Bader charge analysis
2. Open step 2.2 for further instructions

Here we can customize the calculation parameters. The settings are divided into several tabs:

- Basic settings: top-level calculation settings
- Advanced settings: fine-tune the calculations
- Plugin settings: parameters for plugin calculations, e.g. the Bader charge plugin

Note that the app pre-configures defaults for most parameters.

#### Tasks

1. Select Insulator electronic type
2. Select Fast protocol
3. A new tab "Bader charge" is now present: open it and follow the instructions there.

Bader charge calculations require using PAW Pseudopotentials. Here you can leave the default option and click the confirm button to proceed with next step.

In the submission step, we define the computational resources to be used in the calculations. The global resources are used to define resources across all workflow calculations. Optionally, you can override the resource settings for specific calculations.

Warning: If running locally (for example, on the AiiDAlab demo server), we recommend keeping nodes and CPUs at the default minimum of 1 each.

Once the resources are defined, we can optionally customize the workflow label (pre-filled according to the settings of steps 1 & 2), as well as provide a detailed description of the workflow. Once we are ready, we can submit the workflow. You first need to select which code (code executable + computer where this will run) to use for each step of the workflow. The Quantum ESPRESSO app should always install a local Quantum ESPRESSO executable that is sufficient for this tutorial, but you can setup additional codes installed on remote supercomputers. For more information on how to set up codes, please refer to the corresponding documentation.

#### Tasks

1. Check that the the default options in the "Global resources" panel are the expected ones. Specifically: select 1 node and 1 CPU for each of the codes. Unless you want to run elsewhere, use the default codes on the AiiDAlab server (ending with `@localhost`) that are available from the dropdown menus.
2. (Optional) customize the workflow label
3. (Optional) add a workflow description
4. Click the Submit button to proceed

Warning: The workflow may take a moment to submit.
Below you can monitor the status of the calculation, that might take several minutes to conclude even if we are using the fast protocol. A summary of calculation parameters is also provided. Raw input and output files may be downloaded upon workflow completion, as well as an AiiDA archive containing the full calculation provenance (that can be reimported by other AiiDAlab users and allows to reload the calculation).

#### Tasks

1. If not already there, switch over to the Status panel
2. Monitor the calculation status. Once the calculation is complete, switch over to the Results panel for further instructions

Here in the results panel, each tab will open results pertaining to a specific calculation submitted by the workflow.
See further instructions below in the "Bader charge" tab.
When Bader charge results are available, the Load results button will become active allowing us to load the results from AiiDA.

#### Tasks

1. Once the calculation is complete, click on the Load results button to load the available results

#### Tasks

1. Click the row in the result table to highlight the specific atom for which the Bader charge is being calculated.

#### Post-guide exercises

1. Use the app to compute the Bader charge of PtO₂.
   - Compare the Bader charge of PtO and PtO₂. What differences do you observe?